@@ -219,8 +219,9 @@ def _cleanup(scratch_file):
 # initialize io
 # =============
 
-def initialize_io(A, max_mem, num_blocks, assume, triangle, mixed_precision,
-                  parallel_io, scratch_dir, flops, verbose=False):
+def initialize_io(A, t, d, max_mem, num_blocks, assume, triangle,
+                  mixed_precision, parallel_io, scratch_dir, check, flops,
+                  verbose=False):
     """
     Initialize the io dictionary.
     """
@@ -232,6 +233,28 @@ def initialize_io(A, max_mem, num_blocks, assume, triangle, mixed_precision,
         dtype = A.dtype
     order = 'F'
 
+    # Check t
+    if not numpy.isscalar(t):
+        raise ValueError('"t" should be a real scalar number.')
+    t = float(t)
+
+    # Check d
+    if numpy.isscalar(d):
+        d = float(d)
+
+        if d == 0.0:
+            d = None
+
+    elif isinstance(d, numpy.ndarray):
+        if d.ndim != 1:
+            raise ValueError('"d" should be a 1D array.')
+        elif d.size != n:
+            raise ValueError('Sizes of "d" and "A" do not match.')
+        elif d.dtype != dtype:
+            d = d.astype(dtype)
+    else:
+        raise ValueError('"d" should be a scalar or 1D array.')
+
     # Initialize
     temp_file = None
     temp_dir = None
@@ -284,6 +307,10 @@ def initialize_io(A, max_mem, num_blocks, assume, triangle, mixed_precision,
                                      numpy.uint64)):
         raise ValueError('"num_blocks" should be an integer.')
 
+    else:
+        # Avoid numpy's int types
+        num_blocks = int(num_blocks)
+
     # Block size
     m = (n + num_blocks - 1) // num_blocks
 
@@ -362,9 +389,9 @@ def initialize_io(A, max_mem, num_blocks, assume, triangle, mixed_precision,
 
     # Get device's memory (total and available memory)
     mem_info = Memory.info()
-    mem_avail = mem_info.available
+    mem_avail = mem_info['allocatable']
     mem_avail_hr = human_readable_mem(mem_avail, pad=False)
-    mem_tot_hr = human_readable_mem(mem_info.total, pad=False)
+    mem_tot_hr = human_readable_mem(mem_info['total'], pad=False)
 
     # Determine number of blocks needed on memory
     num_mem_blocks = 1
@@ -393,6 +420,15 @@ def initialize_io(A, max_mem, num_blocks, assume, triangle, mixed_precision,
             (parallel_io not in ['multiproc', 'dask', 'tensorstore'])):
         raise ValueError('"parallel_io" should be either set to None, ' +
                          '"multiproc", "dask", or "tensorstore".')
+    elif (parallel_io == 'multiproc') and \
+            (not sys.platform.startswith("linux")):
+        # We prevent using multiproc in macos and windows since, due to a # bug
+        # (yet I have not resolved it), loading and storing blocks cannot load
+        # or store the actual data from disk, making the blocks empty or zero,
+        # eventually leading to matrix singular, which causes LU or other
+        # decomposition methods to crash.
+        raise ValueError('The argument parallel_io="multiproc" can only be ' +
+                         'used in Linux.')
 
     if parallel_io == 'multiproc':
         A11 = shared_memory.SharedMemory(create=True, size=block_nbytes)
@@ -567,10 +603,16 @@ def initialize_io(A, max_mem, num_blocks, assume, triangle, mixed_precision,
             if verbose:
                 # Get partition info for the scratch directory
                 part_info = Disk.partition_info(scratch_dir)
+                if part_info is not None:
+                    fstype = getattr(part_info, 'fstype', 'not detected')
+                    device = getattr(part_info, 'device', 'not detected')
+                else:
+                    fstype = 'not detected'
+                    device = 'not detected'
 
                 print(f'\n{ANSI.FAINT}Disk:{ANSI.RESET}\n' +
-                      f'filesystem            : {part_info.fstype}\n' +
-                      f'device:               : {part_info.device}\n' +
+                      f'filesystem            : {fstype}\n' +
+                      f'device:               : {device}\n' +
                       f'total disk space      : {disk_total_hr:>8}\n' +
                       f'available disk space  : {disk_free_hr:>8}\n' +
                       f'required scratch size : {ANSI.BOLD}' +
@@ -621,7 +663,10 @@ def initialize_io(A, max_mem, num_blocks, assume, triangle, mixed_precision,
             'dask_A': dask_A,
             'ts_A': ts_A,
             'A': A,
+            't': t,
+            'd': d,
             'cached': cached,
+            'check': check,
         },
         'arrays': {
             'A11': A11,
