@@ -33,8 +33,9 @@ def test_fit_logdet():
     x_fit = numpy.logspace(1, 3)
     y_fit = -x_fit * numpy.log(x_fit)
 
-    flodet = FitLogdet(m=3, n=0, scale_x=1, scale_y=1)
-    flodet.fit(x_fit, y_fit)
+    flodet = FitLogdet(m=3, n=0, scale_x=1, alpha=0, scale_y=1)
+    flodet.fit(x_fit, y_fit, lam=0.0, smooth_interval=[1e3, 1e5],
+               verbose=False)
 
     x_eval = numpy.logspace(3, 5)
     y_eval = flodet.eval(x_eval)                                   # noqa: F841
